from wx.lib.embeddedimage import PyEmbeddedImage

square_brackets = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAAFAAAABPEAYAAAAsAZ6gAAAJJmlDQ1BpY2MAAEiJlZVnUJNZ"
    "F8fv8zzphUASQodQQ5EqJYCUEFoo0quoQOidUEVsiLgCK4qINEWQRQEXXJUia0UUC4uCAhZ0"
    "gywCyrpxFVFBWXDfGZ33HT+8/5l7z2/+c+bec8/5cAEgiINlwct7YlK6wNvJjhkYFMwE3yiM"
    "n5bC8fR0A9/VuxEArcR7ut/P+a4IEZFp/OW4uLxy+SmCdACg7GXWzEpPWeGjy0wPj//CZ1dY"
    "sFzgMt9Y4eh/eexLzr8s+pLj681dfhUKABwp+hsO/4b/c++KVDiC9NioyGymT3JUelaYIJKZ"
    "ttIJHpfL9BQkR8UmRH5T8P+V/B2lR2anr0RucsomQWx0TDrzfw41MjA0BF9n8cbrS48hRv9/"
    "z2dFX73kegDYcwAg+7564ZUAdO4CQPrRV09tua+UfAA67vAzBJn/eqiVDQ0IgALoQAYoAlWg"
    "CXSBETADlsAWOAAX4AF8QRDYAPggBiQCAcgCuWAHKABFYB84CKpALWgATaAVnAad4Dy4Aq6D"
    "2+AuGAaPgRBMgpdABN6BBQiCsBAZokEykBKkDulARhAbsoYcIDfIGwqCQqFoKAnKgHKhnVAR"
    "VApVQXVQE/QLdA66At2EBqGH0Dg0A/0NfYQRmATTYQVYA9aH2TAHdoV94fVwNJwK58D58F64"
    "Aq6HT8Id8BX4NjwMC+GX8BwCECLCQJQRXYSNcBEPJBiJQgTIVqQQKUfqkVakG+lD7iFCZBb5"
    "gMKgaCgmShdliXJG+aH4qFTUVlQxqgp1AtWB6kXdQ42jRKjPaDJaHq2DtkDz0IHoaHQWugBd"
    "jm5Et6OvoYfRk+h3GAyGgWFhzDDOmCBMHGYzphhzGNOGuYwZxExg5rBYrAxWB2uF9cCGYdOx"
    "BdhK7EnsJewQdhL7HkfEKeGMcI64YFwSLg9XjmvGXcQN4aZwC3hxvDreAu+Bj8BvwpfgG/Dd"
    "+Dv4SfwCQYLAIlgRfAlxhB2ECkIr4RphjPCGSCSqEM2JXsRY4nZiBfEU8QZxnPiBRCVpk7ik"
    "EFIGaS/pOOky6SHpDZlM1iDbkoPJ6eS95CbyVfJT8nsxmpieGE8sQmybWLVYh9iQ2CsKnqJO"
    "4VA2UHIo5ZQzlDuUWXG8uIY4VzxMfKt4tfg58VHxOQmahKGEh0SiRLFEs8RNiWkqlqpBdaBG"
    "UPOpx6hXqRM0hKZK49L4tJ20Bto12iQdQ2fRefQ4ehH9Z/oAXSRJlTSW9JfMlqyWvCApZCAM"
    "DQaPkcAoYZxmjDA+SilIcaQipfZItUoNSc1Ly0nbSkdKF0q3SQ9Lf5RhyjjIxMvsl+mUeSKL"
    "ktWW9ZLNkj0ie012Vo4uZynHlyuUOy33SB6W15b3lt8sf0y+X35OQVHBSSFFoVLhqsKsIkPR"
    "VjFOsUzxouKMEk3JWilWqUzpktILpiSTw0xgVjB7mSJleWVn5QzlOuUB5QUVloqfSp5Km8oT"
    "VYIqWzVKtUy1R1WkpqTmrpar1qL2SB2vzlaPUT+k3qc+r8HSCNDYrdGpMc2SZvFYOawW1pgm"
    "WdNGM1WzXvO+FkaLrRWvdVjrrjasbaIdo12tfUcH1jHVidU5rDO4Cr3KfFXSqvpVo7okXY5u"
    "pm6L7rgeQ89NL0+vU++Vvpp+sP5+/T79zwYmBgkGDQaPDamGLoZ5ht2GfxtpG/GNqo3uryav"
    "dly9bXXX6tfGOsaRxkeMH5jQTNxNdpv0mHwyNTMVmLaazpipmYWa1ZiNsulsT3Yx+4Y52tzO"
    "fJv5efMPFqYW6RanLf6y1LWMt2y2nF7DWhO5pmHNhJWKVZhVnZXQmmkdan3UWmijbBNmU2/z"
    "zFbVNsK20XaKo8WJ45zkvLIzsBPYtdvNcy24W7iX7RF7J/tC+wEHqoOfQ5XDU0cVx2jHFkeR"
    "k4nTZqfLzmhnV+f9zqM8BR6f18QTuZi5bHHpdSW5+rhWuT5z03YTuHW7w+4u7gfcx9aqr01a"
    "2+kBPHgeBzyeeLI8Uz1/9cJ4eXpVez33NvTO9e7zofls9Gn2eedr51vi+9hP0y/Dr8ef4h/i"
    "3+Q/H2AfUBogDNQP3BJ4O0g2KDaoKxgb7B/cGDy3zmHdwXWTISYhBSEj61nrs9ff3CC7IWHD"
    "hY2UjWEbz4SiQwNCm0MXwzzC6sPmwnnhNeEiPpd/iP8ywjaiLGIm0iqyNHIqyiqqNGo62ir6"
    "QPRMjE1MecxsLDe2KvZ1nHNcbdx8vEf88filhICEtkRcYmjiuSRqUnxSb7JicnbyYIpOSkGK"
    "MNUi9WCqSOAqaEyD0tandaXTlz/F/gzNjF0Z45nWmdWZ77P8s85kS2QnZfdv0t60Z9NUjmPO"
    "T5tRm/mbe3KVc3fkjm/hbKnbCm0N39qzTXVb/rbJ7U7bT+wg7Ijf8VueQV5p3tudATu78xXy"
    "t+dP7HLa1VIgViAoGN1tubv2B9QPsT8M7Fm9p3LP58KIwltFBkXlRYvF/OJbPxr+WPHj0t6o"
    "vQMlpiVH9mH2Je0b2W+z/0SpRGlO6cQB9wMdZcyywrK3BzcevFluXF57iHAo45Cwwq2iq1Kt"
    "cl/lYlVM1XC1XXVbjXzNnpr5wxGHh47YHmmtVagtqv14NPbogzqnuo56jfryY5hjmceeN/g3"
    "9P3E/qmpUbaxqPHT8aTjwhPeJ3qbzJqamuWbS1rgloyWmZMhJ+/+bP9zV6tua10bo63oFDiV"
    "cerFL6G/jJx2Pd1zhn2m9az62Zp2WnthB9SxqUPUGdMp7ArqGjzncq6n27K7/Ve9X4+fVz5f"
    "fUHyQslFwsX8i0uXci7NXU65PHsl+spEz8aex1cDr97v9eoduOZ67cZ1x+tX+zh9l25Y3Th/"
    "0+LmuVvsW523TW939Jv0t/9m8lv7gOlAxx2zO113ze92D64ZvDhkM3Tlnv296/d5928Prx0e"
    "HPEbeTAaMip8EPFg+mHCw9ePMh8tPN4+hh4rfCL+pPyp/NP637V+bxOaCi+M24/3P/N59niC"
    "P/Hyj7Q/Fifzn5Ofl08pTTVNG02fn3Gcufti3YvJlykvF2YL/pT4s+aV5quzf9n+1S8KFE2+"
    "Frxe+rv4jcyb42+N3/bMec49fZf4bmG+8L3M+xMf2B/6PgZ8nFrIWsQuVnzS+tT92fXz2FLi"
    "0tI/QiyQvpNzTVQAAAAgY0hSTQAAeiYAAICEAAD6AAAAgOgAAHUwAADqYAAAOpgAABdwnLpR"
    "PAAAAAZiS0dE////////CVj33AAAAAlwSFlzAAABLAAAASwAc4jpUgAAAAd0SU1FB+MBDg8P"
    "AXp49msAAAtfSURBVHja7Z17bFRVHsc/595pO22F0gKtkKpERNjUtJatjLI2iqusSzARSFci"
    "6IYsLKxAoSZudjXGRzDiZl15RZAs2c3WSgBRs8QHEdGtLgI2LQhqJQVBpUUefQClwzzu2T/u"
    "Pe1M19qWzqvt+fzzm3bu3Pv7/e73/s5jJueARhNHRF9PUFVVVSWlTuRgo6ioqEiIOAhQC04T"
    "SUEKLTxNPAUptPA08RSiEVvhPfZ32x4N2FZdQdv42ks32nbLZtve9Vyk7nh3OhLRFd5/nUAm"
    "P65rQX/mT06hekFGuhIakXV09vrwJ0sLb2Cw0rJtID/SldCITOXb/qhtNy/SN2sgYx4MLzCp"
    "2/t6xj5WwNVTbDvzRX1zBiOXZva1EhpXVvnGNtu2dLe+CRoI3h7jCliXoZOuCZHRx7Z9UEZZ"
    "gA/v08nWdE1FtCvgvLE6yZruuec3URLgncN1cjXd8+uDERbg+EMJF6NwJtFduABIIgmAZJJ/"
    "0qrjjUjPgV5xL9wI86s7/1Wc6niBSDwB3veHnh7p6tlhPy9zXrwfd8G5cQMwgQkAYpqYBsBk"
    "JgOQTTYAJmbY5y9yEYBqqgF4gzcAZLW0/26lFQCJjEkc6aQDiIliIgAzsac0JmL/fRVXhQ80"
    "CQJwmtMA7GEPgHxHvgNALbUAePHGJI6f5IZlzovlERKgx4r7Q+UITywRSwCMoBEEMHeYOwDM"
    "RrMRQGSJLACRL+xZ+zbaAGSZLAOwtlnbAPzH/ccBrKetp0PfbxdqtFDCe0m8BGAcNY4CJI1J"
    "GgNg5Bl5AGKlWAlAKqkA8nP5OYBslI0AweXB5QDBKcEpAJZpmQBynVwXGnei00MBBsriXvnG"
    "MQ7AOGmcBEgrSisCGD5v+DyADFeGC8C1xbUFgOMcDz2NXCqXAlwov1AOcGbXmV0AF5648ASA"
    "NcGaACA/kZ8AYBHZh85palXFM2qNWoAhu4bsAhhZPrIcYEjlkEoA8YP44UfvxILAAoCWQEsA"
    "4FzuuVyAS1WXqgCC44LjADjEofhXwogJkPtV/PHqI4liUQxgXmteC5C5NXMrwIjAiEDYl9xb"
    "2fqT51vHOoDmuc1zpYS2nLYcAN903/SwPlmUBMh0pgO4al21ACN2jtgJkPFqxqthcTh+dsdp"
    "12mXlHD5zst3AljFVjGA3CA3hDXdCUoPO+LyfMJVwOFpwwGyn8x+MvdE70+bVJJUAiDSRBoA"
    "IxkZ1U69Oq9zHXVd5UdvUXGrPKi8qDwl5uCkz9MwccTpC7GYxQBGvpEPkLQxaWPyrpAulifd"
    "M/RBKK0trf3LKXh46sNT/+iBkpaSlsUH4I6Td5y8/1dwfuz5sQDWdMuufPvZH5XKp1Dnda6j"
    "rqv8UH4pP5XfKg4VV/sD5MSt8qDy0p6nfoKL/oZK8DVcAyA90iNvB1awAiDXl+sbuwBWj189"
    "/rEcaK1rrWMveFd5VwF4n/E+w3vQVNlUCRDYHtgOICfJSQAc4Ug0BSh3y90Agf2B/QBNzU3N"
    "ABX5Fflvvgfup9xPAbjr3HXshfTx6eMBdvp2+jYvgK/5mprXQC6QC+TtQD31/VF4/a8CdkZN"
    "N6xgBfM7/t06rHXYhfvB/6X/S4D6nPocgPrS+lKAs01nmwC81d5qALlQLgwbtESr067O61xH"
    "XVf5ofxSfiq/VRwqrnZU3CoP/ZT+J0B1Ix0rG2RD6HjXOmgdDN4NgSOBIwD+Gn8NgP+E/wRA"
    "sCBYAGDNteYCyDflmwD48MXEf+c66rrKD+WX8lP5reJQcbWnQcXdKR9agLHGCu+1ycPyMPuA"
    "13k9bDS4gQ0AcofcAcA3fAPAZS7H9Aaq66jrOn60+6X8VH6rOFRcXcStK2AiVUgZ0ukPOFNH"
    "ajpC2USpGMqPzv4pv1Ucsr/WuMEmQI0WoEajBajRAtRotAA1WoAajRagRgtQo9EC1GgBajRa"
    "gBotQI1GC1CjBajRAtRotAA1WoAajRagRgtQo9EC1GgBajRagBotQI1GC1CjBajRaAFqtAAT"
    "G0HHAo1qZdLONtEWcOyJn2Lg3SrXABBbuJRyyOEaII88ADx4wo5X/1fr6jXTDHSsjhWrFVjU"
    "Kv4Z2Nue5ZILwCQmhfndQENYXADf/0jcugLGUHChdihDyQoJqNgoFqvBmGPMATAvmBcAzGaz"
    "GcCcYc4AMG4ybgIQs8QsoGNbhGjfVrW/RwEFAKJRNAKYeWYegHnKPAVgnjfPQ0ccKq52VNyd"
    "86ErYJRRFcrZsEXMErN4xHlvEaTMTpmd9ktIuS7lOs5D1sysmQDeLd4tAP5cfy6AN8+bB+C7"
    "z3cfALdwC4CslJVAx+pUkX5wnDWijSwjCyCpOKkYwF3jrgFI/jD5QwD3IvcigJQDKQegIy4+"
    "5dOwuK/m6phW7kEvQNVUnuMcAOtZL/4DXM/1AP75/vneFthbtrfs8uNwNudsTkMdeNd411zK"
    "g6Y5TXPOjIGCaQXTindB6sTUiUY5+Ev8JWEVKkoCFJPFZACjwWgAyPBkeADerXi34qNCyFqV"
    "tSrbAvdo9+i0MTCibETZqDzwP+d/ztsCLGMZRkjcpZSykNgtsDloBagS/BZvAViPWI8ABJuC"
    "Te0byW+G79K/S68z4DZuc7ZUCmEbsJa1ABcXX1wsJZxoPdEK4C/wF8RkkHEXdwG4prqmAgyr"
    "GVYDsNBcaE45EHL8V3zF58AHfMC/gVWs4vmOt1Xc1nzLXqD4ZV4GYBSjBmIfMCXuTe63fAtg"
    "PWs9C+DN9GYCnFtzbs2pjwff9IWKW+VB5UXlqb80yT2sgOL3zotNcROgs71B0BP0ALQcbzkO"
    "8NoLr71w4FMILA8sv1wB7kJ3YWoWCFOYxjR7LWa5EYLzgvMCj0HTjqYdZ/4KX+R/kW89BKnv"
    "p75vlAMHORhaoSKOWul0N/Yq+bWBWoDmwuZCgFfWv7L+w5sg89bMW0euBtdR19Gkr0A8IB4Q"
    "S0EGZdB6B7w13pq2RnCNco1KWQItbS1tAMExwTGheeovAhRVVVVVsltXX6qx7fKb4zbqzbLH"
    "uqJe1AO4PC4PgHufex9A8qjkUQBmoVkIwFzmhk6zSJ/0Afhn+GcAeA95D4UOQuS98t6YDEKc"
    "QYPaE659EFLuLgdILk4uBhB5Ii80birs3aCDNcEaAF+DrwHA6/F6AAL7AvsA5Gg5GoBGGuMv"
    "RNHlyLyoqKhIiB5XwFN/c178K24VUAkpX+YDBDYFNgG0FrUWAVw6dukY2JUPgLd5O7TyyCPS"
    "3v9jBjMA5B5p7za5Xdr7hHwmPwOit1mhiuMMZwCsRqsRwFftqwYIFAbsB8fZzbN9s0U1X+hY"
    "eUweA5CZMhNAbpKbAOSD0t7Gpo66AdgEby+y7cr4eaoW73YSLKfIKQAyW2YDiGFiGNCxr67a"
    "flXhzPPJVmn/X217qiailfCifeNUZXWafJklswCCh4OHAUSGyAgTXmcB383dALJZ2n4PYUiY"
    "8BJib7jW30a4CW7PQuI9VZ0nYLubkO0ssESpFD2dUE5U/8PYM9a2vzjWXRPcy29C2p5PuFg7"
    "b9SiOvtd2UTd2KW/+x/Gy+9FehpGDYKHotF0S8WNURLg0iU6uZqueX1Zbz9xhT9GWDdFJ1vz"
    "/5Ss6bUAVWewl5XwI6fj8r1OugYeSrrST/bx51iG8ws13wl9EwYja+wNF3k1ECcBKlLG6Io4"
    "mJjtfCW7zN3bT3ZucY2u3uhbRdR9xIHF0TTb/uxF226ZH6kzdym53k1Qd8fadbb93Xnbpv5Z"
    "39REpvJm2/7Dmff957S+nrGrAhcjAXbFDc6PzGdV2fbqR21rrXWa9I3OgZe1KPpUZ0Y61m9b"
    "11u23VZq23POd6xflkT6yt21rN02urERomag0dMuXa97fVqQmkgI74oFqIWo6YvgIiZALUwt"
    "tEjwP/qa/nRckJTxAAAAJXRFWHRkYXRlOmNyZWF0ZQAyMDE5LTAxLTE0VDIwOjE1OjAxLTA1"
    "OjAw0V7SIQAAACV0RVh0ZGF0ZTptb2RpZnkAMjAxOS0wMS0xNFQyMDoxNTowMS0wNTowMKAD"
    "ap0AAAAUdEVYdHBkZjpWZXJzaW9uAFBERi0xLjUgBVwLOQAAAABJRU5ErkJggg==")

curly_brackets = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAAFUAAABPEAYAAADKKFXkAAAJJmlDQ1BpY2MAAEiJlZVnUJNZ"
    "F8fv8zzphUASQodQQ5EqJYCUEFoo0quoQOidUEVsiLgCK4qINEWQRQEXXJUia0UUC4uCAhZ0"
    "gywCyrpxFVFBWXDfGZ33HT+8/5l7z2/+c+bec8/5cAEgiINlwct7YlK6wNvJjhkYFMwE3yiM"
    "n5bC8fR0A9/VuxEArcR7ut/P+a4IEZFp/OW4uLxy+SmCdACg7GXWzEpPWeGjy0wPj//CZ1dY"
    "sFzgMt9Y4eh/eexLzr8s+pLj681dfhUKABwp+hsO/4b/c++KVDiC9NioyGymT3JUelaYIJKZ"
    "ttIJHpfL9BQkR8UmRH5T8P+V/B2lR2anr0RucsomQWx0TDrzfw41MjA0BF9n8cbrS48hRv9/"
    "z2dFX73kegDYcwAg+7564ZUAdO4CQPrRV09tua+UfAA67vAzBJn/eqiVDQ0IgALoQAYoAlWg"
    "CXSBETADlsAWOAAX4AF8QRDYAPggBiQCAcgCuWAHKABFYB84CKpALWgATaAVnAad4Dy4Aq6D"
    "2+AuGAaPgRBMgpdABN6BBQiCsBAZokEykBKkDulARhAbsoYcIDfIGwqCQqFoKAnKgHKhnVAR"
    "VApVQXVQE/QLdA66At2EBqGH0Dg0A/0NfYQRmATTYQVYA9aH2TAHdoV94fVwNJwK58D58F64"
    "Aq6HT8Id8BX4NjwMC+GX8BwCECLCQJQRXYSNcBEPJBiJQgTIVqQQKUfqkVakG+lD7iFCZBb5"
    "gMKgaCgmShdliXJG+aH4qFTUVlQxqgp1AtWB6kXdQ42jRKjPaDJaHq2DtkDz0IHoaHQWugBd"
    "jm5Et6OvoYfRk+h3GAyGgWFhzDDOmCBMHGYzphhzGNOGuYwZxExg5rBYrAxWB2uF9cCGYdOx"
    "BdhK7EnsJewQdhL7HkfEKeGMcI64YFwSLg9XjmvGXcQN4aZwC3hxvDreAu+Bj8BvwpfgG/Dd"
    "+Dv4SfwCQYLAIlgRfAlxhB2ECkIr4RphjPCGSCSqEM2JXsRY4nZiBfEU8QZxnPiBRCVpk7ik"
    "EFIGaS/pOOky6SHpDZlM1iDbkoPJ6eS95CbyVfJT8nsxmpieGE8sQmybWLVYh9iQ2CsKnqJO"
    "4VA2UHIo5ZQzlDuUWXG8uIY4VzxMfKt4tfg58VHxOQmahKGEh0SiRLFEs8RNiWkqlqpBdaBG"
    "UPOpx6hXqRM0hKZK49L4tJ20Bto12iQdQ2fRefQ4ehH9Z/oAXSRJlTSW9JfMlqyWvCApZCAM"
    "DQaPkcAoYZxmjDA+SilIcaQipfZItUoNSc1Ly0nbSkdKF0q3SQ9Lf5RhyjjIxMvsl+mUeSKL"
    "ktWW9ZLNkj0ie012Vo4uZynHlyuUOy33SB6W15b3lt8sf0y+X35OQVHBSSFFoVLhqsKsIkPR"
    "VjFOsUzxouKMEk3JWilWqUzpktILpiSTw0xgVjB7mSJleWVn5QzlOuUB5QUVloqfSp5Km8oT"
    "VYIqWzVKtUy1R1WkpqTmrpar1qL2SB2vzlaPUT+k3qc+r8HSCNDYrdGpMc2SZvFYOawW1pgm"
    "WdNGM1WzXvO+FkaLrRWvdVjrrjasbaIdo12tfUcH1jHVidU5rDO4Cr3KfFXSqvpVo7okXY5u"
    "pm6L7rgeQ89NL0+vU++Vvpp+sP5+/T79zwYmBgkGDQaPDamGLoZ5ht2GfxtpG/GNqo3uryav"
    "dly9bXXX6tfGOsaRxkeMH5jQTNxNdpv0mHwyNTMVmLaazpipmYWa1ZiNsulsT3Yx+4Y52tzO"
    "fJv5efMPFqYW6RanLf6y1LWMt2y2nF7DWhO5pmHNhJWKVZhVnZXQmmkdan3UWmijbBNmU2/z"
    "zFbVNsK20XaKo8WJ45zkvLIzsBPYtdvNcy24W7iX7RF7J/tC+wEHqoOfQ5XDU0cVx2jHFkeR"
    "k4nTZqfLzmhnV+f9zqM8BR6f18QTuZi5bHHpdSW5+rhWuT5z03YTuHW7w+4u7gfcx9aqr01a"
    "2+kBPHgeBzyeeLI8Uz1/9cJ4eXpVez33NvTO9e7zofls9Gn2eedr51vi+9hP0y/Dr8ef4h/i"
    "3+Q/H2AfUBogDNQP3BJ4O0g2KDaoKxgb7B/cGDy3zmHdwXWTISYhBSEj61nrs9ff3CC7IWHD"
    "hY2UjWEbz4SiQwNCm0MXwzzC6sPmwnnhNeEiPpd/iP8ywjaiLGIm0iqyNHIqyiqqNGo62ir6"
    "QPRMjE1MecxsLDe2KvZ1nHNcbdx8vEf88filhICEtkRcYmjiuSRqUnxSb7JicnbyYIpOSkGK"
    "MNUi9WCqSOAqaEyD0tandaXTlz/F/gzNjF0Z45nWmdWZ77P8s85kS2QnZfdv0t60Z9NUjmPO"
    "T5tRm/mbe3KVc3fkjm/hbKnbCm0N39qzTXVb/rbJ7U7bT+wg7Ijf8VueQV5p3tudATu78xXy"
    "t+dP7HLa1VIgViAoGN1tubv2B9QPsT8M7Fm9p3LP58KIwltFBkXlRYvF/OJbPxr+WPHj0t6o"
    "vQMlpiVH9mH2Je0b2W+z/0SpRGlO6cQB9wMdZcyywrK3BzcevFluXF57iHAo45Cwwq2iq1Kt"
    "cl/lYlVM1XC1XXVbjXzNnpr5wxGHh47YHmmtVagtqv14NPbogzqnuo56jfryY5hjmceeN/g3"
    "9P3E/qmpUbaxqPHT8aTjwhPeJ3qbzJqamuWbS1rgloyWmZMhJ+/+bP9zV6tua10bo63oFDiV"
    "cerFL6G/jJx2Pd1zhn2m9az62Zp2WnthB9SxqUPUGdMp7ArqGjzncq6n27K7/Ve9X4+fVz5f"
    "fUHyQslFwsX8i0uXci7NXU65PHsl+spEz8aex1cDr97v9eoduOZ67cZ1x+tX+zh9l25Y3Th/"
    "0+LmuVvsW523TW939Jv0t/9m8lv7gOlAxx2zO113ze92D64ZvDhkM3Tlnv296/d5928Prx0e"
    "HPEbeTAaMip8EPFg+mHCw9ePMh8tPN4+hh4rfCL+pPyp/NP637V+bxOaCi+M24/3P/N59niC"
    "P/Hyj7Q/Fifzn5Ofl08pTTVNG02fn3Gcufti3YvJlykvF2YL/pT4s+aV5quzf9n+1S8KFE2+"
    "Frxe+rv4jcyb42+N3/bMec49fZf4bmG+8L3M+xMf2B/6PgZ8nFrIWsQuVnzS+tT92fXz2FLi"
    "0tI/QiyQvpNzTVQAAAAgY0hSTQAAeiYAAICEAAD6AAAAgOgAAHUwAADqYAAAOpgAABdwnLpR"
    "PAAAAAZiS0dE////////CVj33AAAAAlwSFlzAAABLAAAASwAc4jpUgAAAAd0SU1FB+MBDg8N"
    "HsVGmRwAABbZSURBVHja7Z17fI91/8efn+t73mab2cyhzSTy4yYyJSV0I1RuTM463FghKin3"
    "HXeUulVIBznd3PePRMqpH8kjhyg1CuWWZY5z3MzGTt9t3+Pn98f1vcxWs++Ytc31+udjs+t9"
    "nV7X+/M+fj6gQ0cVgLheAXv27Nkjpf4gdVwdsbGxsUJUIFF1Yur4I4grdILqqAqEFTpBdVQF"
    "wioVS9AX96rjcd/P2hn0sWqN345Ux8FR5cWM0vgmbixBPwlTxwEZus64GfDZd+rY/77y1rBK"
    "+V7owF1FvzydoDcXHr236Pvv9FB5SVbKR5OufkEdV9ytvywdhfh6g0+BlZkXxfl4nRr1vc7q"
    "2Hem/lJ0lIwVvpl26FvXKkFcmyZtlKmOR0P0l6DjGmjnd1hUs1WvUaPqBNVxPTi1vawmQBmJ"
    "+thu/SHruH5EdVTHoLgyO1P+4clG+kPWUX54bcMNImqnWvrD1VF+eL7A3780+vdntx+ots9K"
    "8X2swpf8KGnUIFFdTy/eIqP2+9/4Db7jtfMUP19xucXH0uTfJPCTqG2e9/1jc9V1NH3EMPru"
    "OYQQAHGbuA2AVrQCoDnNAYgmGoAwwoocf5KTAGxjG4DcLlXH4DSnAXDhAsCCBYDGNAYQ3UQ3"
    "AO5DzdpEEgmAAwcAqaQCcIITABzkIIA8IA8UOW8uuQB48FQfGjZ/Vh0PvnedU//d3ir8KarE"
    "rE1tAPG4eBxAaae0A1DSlDQAU01TTQDLect5AGsraysAW4otBcCWZEsCsDxveR7A+LzxeQBl"
    "tjIbQHQVXVX/gKAi51EUBcDU2tQawJpmTQOw5dvyAWwJtgQA64/WHwHMg82DAYxTjVMBDBMN"
    "EwGEQziKED6Y4CIaukrDlVtOGtX9fJW7dzNmABErYovMwDlKDoClmaUZgC3HlgMQuChwEYAt"
    "2ZYMYF5pXgmgTFQmAsjP5GcABT8W/AiQ2TWzK0CWO8sN4PzC+YU6+dAGQKwVawFsPW09AUKX"
    "hC4BCHkl5BUAc6A5EIC+9AVwG91GAOdzzucA8p35TgD7MPswgPwF+QsAnKecpwC8y73LAWRf"
    "2ReAZJKrrqaVpV6zv19j76qmQUVb0RZALBQLAcwHzQcBwtLD0gFi3ox5E+BUw1MNc87AmF/G"
    "/DJ2O9yafmt6dEswzzXPFQKMDYwNhADTBNMEIaBGXI04IWBE8ojkwZ3A+rT16SIa9V7uBVD2"
    "KfsAAhIDEgFuGXfLONPtELAoYJEQYHzG+IwQYBxqHCoE2IRNKEvh3o73drzna5g2bNqwN5uD"
    "Y5NjE0BUUFQQQMj3Id8DmNqa2gIozZRmADShCQAGDFVQpaaXarn5l5maaVfHFwIqvQ1al7oA"
    "SgelA4CloaUhQPiX4V8CJI5LHJf5OQzcNHBTy1pw/sT5E6c7XEVuN7oBPBr5aOSYRpDRPaN7"
    "6hwY/ujwRyffAbEJsQmt6kLeA3kPAHhbeVsBKAlKAkBI05CmAIstiy0LL8G+IfuGfDsCTow8"
    "MfLX7+FQ5KHIvaml316XR7o80m8aLG+zvM1nk8G12bUZ4OKfL/4ZwNnL2QtAhknVpr7Eparj"
    "hDV5WB2PfFFO4alKDBMmADFUDAUwPGt4FiD0aOhRgKS/J/09dw50ntd5Xs3eJRM0sH1g+xrv"
    "w/pf1/96IgNkLVlLSli0edHmOUfh420fb1vVHe766a6fWtWFgjoFdQC8y7zLAOQOuQNARsgI"
    "APsH9g8ARuSPyI+vCUu6Len20WrYG7U3ak8KSCmllDB9x/Qdn35Y8u1tWb9l/ap/QO2ptacK"
    "AZmZmZkANbrW6ApgmG6YDiDaiXbVx3atTkTVNGlNagIIm7ABWC5ZLgFEpkemA9w/8/6ZNcaW"
    "Lu7CgAsDssdCu8R2iTFhcMR6xApw2nLaApDWI60HQO6G3A0A7iR3EoB8WD58pdcu82U+gKu/"
    "qz9AFlmqc78gdQFAcrvkdgDH2x9vDzAmYUzCo6Nh3/x98/2pvbj/6fufrjcUaq2vtR7A+J5R"
    "9ZinM71I1EEnauUiqhZmUvYqewFs8bZ4gHU/rfvpUNvSxcx+aPZD673gXuNeA3DBdsEGYF9u"
    "Xw7geMzxGIB7qnsqgHeadxqAbC7VcNZRjgLgxAkgf5A/AHiTvEkAnnRPOoAryZUEUDCqYBRA"
    "9srslQCp+1P3A7SIahEFMCpkVMi0nSVfb8bYjLEpH0N+Qn4CgPlL85cA4oK4cOWH+5t4bfWO"
    "o1YBjdqIRgBikVgEYD1tPQ3wyf5P9n/gx+fYeFLjSS3rQ067nHacA1dbV1sAb2tvawA5SA66"
    "0ku/HIjXbMHfBEpwA3Ce8wDyG/lNkSk5kEAA72LvYgDHMMcwAPs4+zgAu9fuzW5d+nVvj9oe"
    "dTAC2nraeppfAOEW6nlroWYRz3FO16iVCaGEAoidYieAcaJxIoA51Zxq8aP0wf2W+y3nq+C5"
    "5LkEIINkEAAHUAPuBRQUCf/466QUzzBpBLajOqjf8A2ADJbBAF7plQCeJE+S9xE/NE1/Y3/T"
    "FFAGKYMAxFQxFUAEisDqpFGrD1G1sIwWplnNagARI2LESD/41Fv2lv8DvMu7AJzhTBFilXvo"
    "0EdgTX4mmQDysDwMqJmpH/yYUP4r/iuCQEwSkwCoT33dmapKhNUyN5FEivp+HJdLLlkUpjQ1"
    "DVhR+L1cvz9XEEoo4YANW3UkaPUl6u/bsWUnTFWy0UX1f4U3B1F16ETVoUMnakXbiPIPPv+V"
    "zpUTp89a9t8E0IlaxWy24qM/d5lJJulAPvkV6kxpBNXCVfvYp0Ut5EI/jjdjxkphOWM1JaxS"
    "je5EvRef9yvq+3z9xjSmhR98aSlbylyQb8g3ADjL2QohrC+TxWa1KF3ulrsBvG6v2zvdj+NH"
    "MlJMAjrQoUi0Qw9PVTLN6StGoQENAMQ74h0A8YJ4AUBJVBKVXqWLc692r3a9Ad5PvJ8AyKly"
    "KoC0S/sNjQb4MluymWwG4L7HfQ9A+K7wXXWOl364IcWQYpgDyjlFzUBpuf5wwtU/8IXrqrim"
    "rTpELR4fbUpTAPG0UOtBB4gBAMZuxm4Atm9t3wIEzAiYEeRHC1mngE4BzVPAFegKBJAmqX4A"
    "GdyY9bM04p/iFICcJWcBOFo7WgN0Cu4U/Jf/LV1Mdkx2zKWOYFttWw1gHGUcBSCcwgkg4oSa"
    "l/OlmKlBjSLPUydqOWnMAAIAREfREUCcE+cADC0MLQCMfYx9AGz7bfsBwg6GHQQghxyABV8v"
    "+HrKqyWfJqJBRIP6nSDgUMAhANdo12gAWUfWuVLjlbtG9cmTJ+VJAO9473iAgmMFxwDapbRL"
    "aTqsdDFT6k+p//i3EPZF2BdQWP9qGW4ZDmDYYdgBoOQpeaBmsuCKckAr1qqgcSsvUX1lamK4"
    "GA6g9FB6AFjSLekANd6t8S5AxPiI8QAxr8e8DlCwtmAtQK1naj0Tcmfpp1n5+srXD7wIF80X"
    "zQCu2a7ZAExCTUk6yuR7l12j+jS2TJNpAI4CRwGA4YThBMDcOXPnbOlSsphjyceSf2kDvQb3"
    "GvzE1xC8JXgLQJQSpQCErwtfB1Dj7RpvA5i7mrsCiAJRACD6ir5FTCidqGXUpFFEAYhpYhqA"
    "9a/WvwJErohcAZCTlZMF8Pn+z/dvOwx9N/fdPHQ0NLjQ4IIQYI+zx2X/9FvxUfOi5jU+CTva"
    "72ifZYfmYc3DavaE7FnZswC8I7wjAOT38vsKcaZ8H4J8Vb4K4D7kPgRw6ZVLrwAMOjfo3J83"
    "w7rcdblHr2Jrr1+xfsWSByDEHeIWAkafHX12wgXYbdltSWoEWUuzlsp1ENEkogmAxWvxAoi7"
    "xF1AYVdsJdWsxspKVNFQNARQ+in9AGxDbUMB6l6qe8n8BLiHuYe5lpQurk5cnbjok7BzzM4x"
    "J6OhUedGnQGyYrJiAFK7p3YHcD3jegZARsmoGzrlF4f2IWgF10vlUgBHPUc9gIyNGRsBHnz7"
    "wbcbfe7rCAD+1fJfLXcMhjGDxgzqthVcL7tedqYVil32n2X/mVXbN2q/7AN3bL5j832NYbV9"
    "tf3bw+C823k3gIgUkQByr9yra9SyIJtsANlH9gHwdPF0AZgdPzv+/+Kge2L3xCHvQpe0LmmP"
    "dixZTOrq1NWnGkDTLk27mP8BE5dPXD7nIITsCdkDYD1sPQygjFHGADCCEUVst4qaQXz1qcxk"
    "JoAh2hANYAu2BQPkZudmA4wcNXLUKy6IPxB/oNOK3xL0suW01rLW1goGvD7g9bGnYMiZIWfG"
    "Pwuz82bnfb4bPM09zUGtGgOQOTKnUgd5Kl1zn/bifOEVYRImAFMdUx2AwKTAJICgVUGrAALn"
    "Bs4FCDwXeA5gxp9m/GnNQnjp4EsH454q+TS1nLWcdX+An90/u8+1Lez2zDmecxzAO8k7CUAm"
    "yIQbagJoXbODxWAo7OMPjQ2NBch5MudJgDuW37HcWAe8t3lv85wvWdymtpvanh0LD/7w4A/1"
    "3oesj7I+ArA3tTcFsI+2jwbIz8rPAnA/5n4MQPaX/a90QisWVbG5T5tqtfhipIwEcJ1xnQHI"
    "9mZ7Ac6/e/5dgOTjyccBjjc/3hxg1NlRZ/vGw8/zfp53tQ8ww5xhTrkLJvSY0GPcKAhrE9YG"
    "wDjCqGrUaUyrEM2qrdhyQpwAMDcwNwCoPa72OIDOSZ2T6tlLJ6hzm3OblNB2UNtB9d6HI1uO"
    "bAE43f90f4D0yemTAeyn7aeLEDRexgOFmTHdmSojtJy3r8LeZ5pdbg1x3eq6FcDxqeNTgOyt"
    "2VsBUtalrANokdYiDSBuTdyap9ZfxevfsXLHB/PBYXFYoHBhCpEr1NU7fJ0D5e5kaPK0RMW/"
    "xb8BbMdsxwB2r9m9JmsopGelZ6UElSzm5cYvN54fB84dzh0AaUfSjgDYR9pHAjinOacBuI+5"
    "jwF4kj3JRTRoRWXgqi1RixM2XV2kQO6SuwDkQjUTLtvL9gDeRd5FAI7GjsYAORNyJgAEbQra"
    "FOrHK/gm75u8X14G03DTcABhEIYrTZAb5jQ2Eo0AlA3KBgDr/db7AVYNWTXkwwdLF3Of6z5X"
    "zxmQPTB7IIBTOtUPOsobBSCHyCEAcpVcBUAiiUWm+EpO0KpD1OImgfZgtd4lbcrSFi1LlakA"
    "3gHeAQCenZ6dbj8WeDDtMu0yB4MyXhl/ZVjshvUeafIiiAAQXuEFML1legvg4s6LO9OiSxfj"
    "HO8c7wgHT0dPRwCZLJOBwuKWa+310ol6gwisad4UUgDYwAYAOU/O42U/eHNUHBWRICaLyUDF"
    "9R751sjiER6BKxZXe0h5yJDox+2HyTB5CORoOVr1RzhS5HlUE1S/Mj8tNemW6oty4PAV7l0d"
    "oYQSweWUbYVVH2ma1bcKIG1RVyEYxCDhx4IZXOISF4A88qrSVK4T9XoII/7g818RrsKM2e+1"
    "TiTVfqFfnag6dKLq0KETtWx2a9mn4KrmTOpErWLQwjC+WgHOc16e9dP7tvLHVcT/Xq+XP1fg"
    "wkUBVT78dPMQVXtRWnhmAAMA5Hl5Xi734/jHeVy8yOUVoy9Xwt9owmrRBV+qVqtiogENuN2P"
    "4z/lU94HfkItatTiytWMsNWHqL4FSGVX2RXA/ZX7KwDXDNcMxz2lH25YaVhp6A7KVmUrAH/n"
    "70Dh8o3Xq2mLa0ytULke9QDEFDEFQPQQPQCUhcpCxQ+qebZ6tnqiCpsC5Ta57bKmrUaErT4B"
    "f99mC3KinAjgyHHkAAyeOHjic1+ULiazdWbrjFvA6rQ6AQxBBjWu+Qu/AIjeojcALXw9rdqy"
    "jsYSanqLE1JLxd7JnQAiXsQDiBZCbanZY1TLDs9YzwDYZtpmBnxa+nXXjK8ZX3sfuDu41S7U"
    "jqgZqiyZpWvUSkhUeUKeAPAO8w4DKNhdsBvgnth7Yhv/o3QxC+IXxE95GWrNqTUHIDgmOAbA"
    "kmxJBjCmGFMADKMMavNcPaFqwu6iO1CYKChWXyr6iD4Ayp3KnQCGjwwfQeGymNb21vYAocNC"
    "hwF4Y7wxAAtZyKuNS7/uDoYOhrBEcDqcaqfARXkRgAtc0DVqZdSoWtHKWdV1coQ6QgFMJpMJ"
    "IO5o3NFRVzEBvtv13a6NWfBQn4f6DFMgunl0c4Cox6MeBwgfGT4SILhJcBMAaw9rjysJqHXB"
    "al2y4lnxLICyVFkKYI22RgOEPBDyAEDtRrUbATTY1WAXQHD34O4AzVzNXE39uO0Pn/vwua8S"
    "IGNZxjIA5z+d/wSQHaVaRq5tnKZr1EoGrfjib/wNwD3WPRYg40zGGYBl7mXuud9Dv/x++aM/"
    "KlnMxnUb1y2TIIQQQsDIDSM3jIuAhNoJtX/9GbaFbAv5ZhWEvxT+EoCltkXdaM3X1an1IIkP"
    "xYcAto22jQCR90XeB2qvVkIArB29dvSW89CrZa+W/X6CwH6B/YSAk8tOLku6ihU8b868OVsn"
    "weAJgyd0bQeZbTLbAHjWeNbAFVVS1SzX72+Fv++mX6j8veDaSikTxAQAQ6AhECBgacBSgIjN"
    "EZsBUg6nHAaYHz4//O0D8FmXz7rMHwcpUSlRJ7aXfpqWPVv2bP8krBm/Zvx3/4acxJxEAO96"
    "73oAQ6ghFCD0UOghgJgDMQdEGdyw1m1at+nwAvRe0ntJ/Fp4asZTM4YeAzFQDAS4mHExA6Bg"
    "TcEaAO8+7z4A+bn8vIgzVSVQeoW/n0Sd9Vd1HL+48n96RYs8Lq+YcotyC4BplmkWQMCUgCkA"
    "QUeDjgIE5QTlANi22LYAbGu4rWHGabhQ70K9s++Bt6m3qXcH5EXkReTMheiU6JQm30O0Pdoe"
    "+SzkvZb3GoDsJXsBKE2VpgCBUYFRAKfHnh6bcRJOpp5MTdoKtlm2WYFfgXhTvKkcg4hFEYvq"
    "R8AD7z3wXthGsPe29wbIeTjnYYDcu3LvAigYWjAUwPWaSz3fi/LFIgTN96sEp7IRdbCPqCuu"
    "k6izfY3Hz7WqOnOFj7BafFJrC96BuiDDKmUVgDJZmQxgyDPkARg9Rg+A6SvTVwCGCINaL/qE"
    "eALAE+QJAnD0cPQAcNztuBvAc8hzCECOk+MAxCqxCsD4hvENAEukJRLAPNY8FsCw2LAYQL4l"
    "3wLwHPMcA3DVddUFcG93bwfwnFcbUDwLPWqhuG9FFe08l+PG2hpWVRK3q6vfcDjnOok60bdm"
    "x5tLq+yz0OKgWjldDDFQuFcqf+EvAOJj8TEUbpLLF6jTkbY3wDu8AyCzpdole0mqvV2+vnxt"
    "FxRtB0ExXagblfkC+cIq1B6sMahdr7/yKwA96QkgjdIIV7SKrGUtgNwn1UJorXWkolcdvKFo"
    "5tut4Ne7r5Oot/m2pz4yrvpY59ouvj6HUouHam3LWhdsiAi5kuiyQKpO20XUMJC2NlVx4hRb"
    "XfBy3NU3CotQi/h8GbXLcU9f9OI3251rcqtlirR0691Pol6OBd0UBRBFiFz85+JE8Zc45S3v"
    "JiNqGcNT+dNvmmdXfJeS4hqtrIQqb3nVAt8u8Pcvy0jUxcHo0FFuWDTIb51btqn/JjQBdPyh"
    "U/41alQNczrrD1nHteOx5f7+ZWxsbKwQoGj/KBvGbvdp1jP6Q9fhP1b6CPrRkLIeeZ25fkVd"
    "ohHnSf0l6LgK2qvDwCHXzLTyuQ5LjK5hdfyOBh3ls0UTynpk8ZleKek/rk/D6jbszY2ht/k0"
    "6PzykqiUxuRrg2bDapLmfKiON1Ec9qZAgS/6M/HNou/742PXKrEk/pVIyWsLW5UVWmo2bo86"
    "1hmvjt4PfKaEtnedQydFRUBocfJ16mD0EXCX7+e9tdXx8A1jRpmJWrGE1XGzo7SZvMyTvE5c"
    "HRVBzOsmqk5YHRVJ0Osmqk5gHTeCkCXh/wETZy6vQ+f86AAAACV0RVh0ZGF0ZTpjcmVhdGUA"
    "MjAxOS0wMS0xNFQyMDoxMzozMC0wNTowMPS4rjEAAAAldEVYdGRhdGU6bW9kaWZ5ADIwMTkt"
    "MDEtMTRUMjA6MTM6MzAtMDU6MDCF5RaNAAAAFHRFWHRwZGY6VmVyc2lvbgBQREYtMS41IAVc"
    "CzkAAAAASUVORK5CYII=")

